==> spip_4.0.4.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=ro
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Ştergeţi statisticile', # MODIF

	// I
	'icone_evolution_visites' => 'Evoluţia vizitelor<br />@visites@ vizite',
	'icone_repartition_actuelle' => 'Afişaţi repartiţia curentă',
	'icone_repartition_visites' => 'Repartiţia vizitelor',
	'icone_statistiques_visites' => 'Statistici',
	'info_affichier_visites_articles_plus_visites' => 'Afişează vizitele pentru <b>cele mai vizitate articole de la început:</b>',
	'info_comment_lire_tableau' => 'Cum se citeşte acest tablou',
	'info_forum_statistiques' => 'Statisticile vizitelor',
	'info_popularite_2' => 'popularitatea site-ului :',
	'info_popularite_3' => 'popularitate : @popularite@ ; vizites : @visites@',
	'info_popularite_5' => 'popularitate :',
	'info_question_vignettes_referer' => 'Atunci când vizualizaţi statisticile, puteţi vizualiza pre-vederi ale site-uri de unde provin vizitele', # MODIF
	'info_question_vignettes_referer_oui' => 'Afişaţi capturile site-urilor de unde provin vizitele',
	'info_visites' => 'vizite :',
	'info_visites_plus_populaires' => 'Afişaţi vizitele pentru <b>articolele cele mai populare</b> şi pentru <b>ultimele articole publicate</b> :',
	'info_zoom' => 'mărire',
	'item_gerer_statistiques' => 'Gestionaţi statisticile', # MODIF

	// O
	'onglet_origine_visites' => 'Originea vizitelor',
	'onglet_repartition_debut' => 'de la început',
	'onglet_repartition_lang' => 'Repartiţia pe limbi',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_admin_effacer_stats' => 'Această comandă şterge toate datele legate de statisticile vizitelor în site, incluzând şi datele de popularitate a articolelor.',
	'texte_comment_lire_tableau' => 'Rangul articolului, în clasamentul de popularitate este indicat cu o marjă ; popularitatea articolului (care este o estimare a numărului de vizite zilnice pe care articolul le va primi dacă ritmul actual de consultare se menţine) şi numărul de vizite primite de la început sunt afişate în mica fereastră care apare la un survol al mouse-ului deasupra titlului.',
	'texte_signification' => 'Barele întunecate reprezintă intrarile cumulate (totalul sub-rubricilor), barele  deschise la culoare reprezintă numărul de vizite pentru fiecare rubrică.',
	'titre_evolution_visite' => 'Evoluţia vizitelor',
	'titre_liens_entrants' => 'Legături în intrare',
	'titre_page_statistiques' => 'Statisticile pe rubrici',
	'titre_page_statistiques_visites' => 'Statisticile vizitelor'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=ro
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'Ştergeţi statisticile', # MODIF

	// I
	'icone_evolution_visites' => 'Evoluţia vizitelor<br />@visites@ vizite',
	'icone_repartition_actuelle' => 'Afişaţi repartiţia curentă',
	'icone_repartition_visites' => 'Repartiţia vizitelor',
	'icone_statistiques_visites' => 'Statistici',
	'info_affichier_visites_articles_plus_visites' => 'Afişează vizitele pentru <b>cele mai vizitate articole de la început:</b>',
	'info_comment_lire_tableau' => 'Cum se citeşte acest tablou',
	'info_forum_statistiques' => 'Statisticile vizitelor',
	'info_popularite_2' => 'popularitatea site-ului :',
	'info_popularite_3' => 'popularitate : @popularite@ ; vizites : @visites@',
	'info_popularite_5' => 'popularitate :',
	'info_question_vignettes_referer' => 'Atunci când vizualizaţi statisticile, puteţi vizualiza pre-vederi ale site-uri de unde provin vizitele', # MODIF
	'info_question_vignettes_referer_oui' => 'Afişaţi capturile site-urilor de unde provin vizitele',
	'info_visites' => 'vizite :',
	'info_visites_plus_populaires' => 'Afişaţi vizitele pentru <b>articolele cele mai populare</b> şi pentru <b>ultimele articole publicate</b> :',
	'info_zoom' => 'mărire',
	'item_gerer_statistiques' => 'Gestionaţi statisticile', # MODIF

	// O
	'onglet_origine_visites' => 'Originea vizitelor',
	'onglet_repartition_debut' => 'de la început',
	'onglet_repartition_lang' => 'Repartiţia pe limbi',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_admin_effacer_stats' => 'Această comandă şterge toate datele legate de statisticile vizitelor în site, incluzând şi datele de popularitate a articolelor.',
	'texte_comment_lire_tableau' => 'Rangul articolului, în clasamentul de popularitate este indicat cu o marjă ; popularitatea articolului (care este o estimare a numărului de vizite zilnice pe care articolul le va primi dacă ritmul actual de consultare se menţine) şi numărul de vizite primite de la început sunt afişate în mica fereastră care apare la un survol al mouse-ului deasupra titlului.',
	'texte_signification' => 'Barele întunecate reprezintă intrarile cumulate (totalul sub-rubricilor), barele  deschise la culoare reprezintă numărul de vizite pentru fiecare rubrică.',
	'titre_evolution_visite' => 'Evoluţia vizitelor',
	'titre_liens_entrants' => 'Legături în intrare',
	'titre_page_statistiques' => 'Statisticile pe rubrici',
	'titre_page_statistiques_visites' => 'Statisticile vizitelor',
];
